==> nextcloud-30.0.12.tar.bz2: nextcloud/apps/systemtags/l10n/gl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s engadida polo sistema",
    "Added system tag {systemtag}" : "Engadida a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Engadida a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s engadiu a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} engadiu a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s retirada polo sistema",
    "Removed system tag {systemtag}" : "Retirada a etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Retirada a etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s retirou a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} retirou a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Vde. creou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Vde. creou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Vde. eliminou a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Vde. eliminou a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminou a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminou a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vde. actualizou a etiqueta de sistema  %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vde. actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizou a etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$sfoi engadida a %1$s polo sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} foi engadida a  {file} polo sistema",
    "You added system tag %2$s to %1$s" : "Vde. engadiu a etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Vde. engadiu a etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s engadiu a etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} engadiu a etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s retirada de %1$s polo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} retirada de  {file} polo sistema",
    "You removed system tag %2$s from %1$s" : "Vde. retirou a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vde. retirou a etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s retirou a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} retirou a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrinxida)",
    "%s (invisible)" : "%s (invisíbel)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse as <strong>etiquetas de sistemas</strong> dun ficheio",
    "Files" : "Ficheiros",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todo etiquetado %s…",
    "tagged %s" : "etiquetado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre a xente.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre a xente. Moi axeitado para equipos.\n\t(Se Vde. é un provedor cunha instalación de multicesións, recoméndase desactivar esta aplicación xa que as etiquetas compártense).",
    "Public" : "Pública",
    "Restricted" : "Restrinxida",
    "Invisible" : "Invisíbel",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Produciuse un fallo ao crear a etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "Produciuse un fallo ao actualizar a etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "Produciuse un fallo ao eliminar a etiqueta",
    "Create or edit tags" : "Crear ou editar etiquetas",
    "Search for a tag to edit" : "Buscar por unha etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Non hai etiquetas para seleccionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nivel da etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Eliminar",
    "Reset" : "Restabelecer",
    "Loading …" : "Cargando…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} vai ser definida e {tag2} vai ser retirada dun filcheiro.","{tag1} vai ser definida e {tag2} vai ser retirada de {count} filcheiros."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} vai ser definida nun ficheiro.","{tag} vai ser definida en {count} ficheiros."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} vai ser eliminada dun ficheiro.","{tag} vai ser eliminada de {count} ficheiros."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} van ser definidas nun ficheiro.","{tags} e {lastTag} van ser definidas en {count} ficheiros."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} van ser eliminadas dun ficheiro.","{tags} e {lastTag} van ser eliminadas de {count} ficheiros."],
    "{displayName} (hidden)" : "{displayName} (agochado)",
    "{displayName} (restricted)" : "{displayName} (restrinxido)",
    "Only admins can create new tags" : "Só a administración pode crear novas etiquetas",
    "Failed to apply tags changes" : "Produciuse un fallo ao aplicar os cambios das etiquetas",
    "File tags modification canceled" : "Cancelouse a modificación das etiquetas do ficheiro",
    "Manage tags" : "Xestionar as etiquetas",
    "Applying tags changes…" : "Aplicando os cambios das etiquetas…",
    "Search or create tag" : "Buscar ou crear unha etiqueta",
    "Search tag" : "Buscar etiqueta",
    "Change tag color" : "Cambiar a cor da etiqueta",
    "Create new tag" : "Crear unha nova etiqueta",
    "Select or create tags to apply to all selected files" : "Seleccionar ou crear etiquetas para aplicalas a todos os ficheiros seleccionados",
    "Select tags to apply to all selected files" : "Seleccionar etiquetas para aplicalas a todos os ficheiros seleccionados",
    "Cancel" : "Cancelar",
    "Apply changes" : "Aplicar os cambios",
    "Failed to load tags" : "Produciuse un fallo ao cargar as etiquetas",
    "Failed to load selected tags" : "Produciuse un fallo ao cargar as etiquetas seleccionadas",
    "Failed to select tag" : "Produciuse un fallo ao seleccionar a etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "A administración do sistema desactivou a creación de etiquetas. Só pode usar as existentes.",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas…",
    "Search or create collaborative tags" : "Buscar ou crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Non hai etiquetas que seleccionar, escriba para crear unha nova",
    "Unable to update setting" : "Non é posíbel actualizar o axuste",
    "System tag creation is now restricted to administrators" : "A creación de etiquetas do sistema agora está restrinxida aos administradores",
    "System tag creation is now allowed for everybody" : "A creación de etiquetas do sistema agora está permitida para todos",
    "System tag management" : "Xestión de etiquetas do sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se está activado, só a administración pode crear e editar etiquetas. As contas aínda poden asignalas e eliminalas dos ficheiros.",
    "Restrict tag creation and editing to administrators" : "Restrinxir a creación e edición  de etiquetas á administración do sitio",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "As etiquetas colaborativas están dispoñíbeis para todos os usuarios. As etiquetas restrinxidas son visíbeis para os usuarios, mais non poden ser asignadas por eles. As etiquetas invisíbeis son para uso interno, pois os usuarios non poden velas nin asignalas.",
    "Assigned collaborative tags" : "Etiquetas colaborativas asignadas",
    "Open in Files" : "Abrir en Ficheiros",
    "List of tags and their associated files and folders." : "Lista de etiquetas e os seus ficheiros e cartafoles asociados.",
    "No tags found" : "Non se atopou ningunha etiqueta",
    "Tags you have created will show up here." : "As etiquetas que creou aparecerán aquí.",
    "Failed to load tag" : "Produciuse un fallo ao cargar a etiqueta",
    "Failed to load last used tags" : "Produciuse un fallo ao cargar as últimas etiquetas utilizadas",
    "Missing \"Content-Location\" header" : "Falta a cabeceira «Content-Location».",
    "A tag with the same name already exists" : "Xa existe outra etiqueta co mesmo nome",
    "Failed to load tags for file" : "Produciuse un fallo ao cargar as etiquetas do ficheiro",
    "Failed to set tag for file" : "Produciuse un fallo ao definir a etiqueta para o ficheiro",
    "Failed to delete tag for file" : "Produciuse un fallo ao eliminar a etiqueta do ficheiro"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12.tar.bz2: nextcloud/apps/systemtags/l10n/gl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etiqueta de sistema %1$s engadida polo sistema",
    "Added system tag {systemtag}" : "Engadida a etiqueta de sistema {systemtag}",
    "Added system tag %1$s" : "Engadida a etiqueta de sistema %1$s",
    "%1$s added system tag %2$s" : "%1$s engadiu a etiqueta de sistema %2$s",
    "{actor} added system tag {systemtag}" : "{actor} engadiu a etiqueta de sistema {systemtag}",
    "System tag %1$s removed by the system" : "Etiqueta de sistema %1$s retirada polo sistema",
    "Removed system tag {systemtag}" : "Retirada a etiqueta de sistema {systemtag}",
    "Removed system tag %1$s" : "Retirada a etiqueta de sistema %1$s",
    "%1$s removed system tag %2$s" : "%1$s retirou a etiqueta de sistema %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} retirou a etiqueta de sistema {systemtag}",
    "You created system tag %1$s" : "Vde. creou a etiqueta de sistema %1$s",
    "You created system tag {systemtag}" : "Vde. creou a etiqueta de sistema {systemtag}",
    "%1$s created system tag %2$s" : "%1$s creou a etiqueta de sistema %2$s",
    "{actor} created system tag {systemtag}" : "{actor} creou a etiqueta de sistema {systemtag}",
    "You deleted system tag %1$s" : "Vde. eliminou a etiqueta de sistema %1$s",
    "You deleted system tag {systemtag}" : "Vde. eliminou a etiqueta de sistema {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s eliminou a etiqueta de sistema %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} eliminou a etiqueta de sistema {systemtag}",
    "You updated system tag %2$s to %1$s" : "Vde. actualizou a etiqueta de sistema  %2$s a %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Vde. actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s actualizou a etiqueta de sistema %3$s a %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} actualizou a etiqueta de sistema {oldsystemtag} a {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etiqueta de sistema %2$sfoi engadida a %1$s polo sistema",
    "System tag {systemtag} was added to {file} by the system" : "Etiqueta de sistema {systemtag} foi engadida a  {file} polo sistema",
    "You added system tag %2$s to %1$s" : "Vde. engadiu a etiqueta de sistema %2$s a %1$s",
    "You added system tag {systemtag} to {file}" : "Vde. engadiu a etiqueta de sistema {systemtag} a {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s engadiu a etiqueta de sistema %3$s a %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} engadiu a etiqueta de sistema {systemtag} a {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etiqueta de sistema %2$s retirada de %1$s polo sistema",
    "System tag {systemtag} was removed from {file} by the system" : "Etiqueta de sistema {systemtag} retirada de  {file} polo sistema",
    "You removed system tag %2$s from %1$s" : "Vde. retirou a etiqueta de sistema %2$s de %1$s",
    "You removed system tag {systemtag} from {file}" : "Vde. retirou a etiqueta de sistema {systemtag} de {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s retirou a etiqueta de sistema %3$s de %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} retirou a etiqueta de sistema {systemtag} de {file}",
    "%s (restricted)" : "%s (restrinxida)",
    "%s (invisible)" : "%s (invisíbel)",
    "<strong>System tags</strong> for a file have been modified" : "Modificáronse as <strong>etiquetas de sistemas</strong> dun ficheio",
    "Files" : "Ficheiros",
    "Tags" : "Etiquetas",
    "All tagged %s …" : "Todo etiquetado %s…",
    "tagged %s" : "etiquetado %s",
    "Collaborative tags" : "Etiquetas colaborativas",
    "Collaborative tagging functionality which shares tags among people." : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre a xente.",
    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de etiquetado colaborativo que comparte as etiquetas entre a xente. Moi axeitado para equipos.\n\t(Se Vde. é un provedor cunha instalación de multicesións, recoméndase desactivar esta aplicación xa que as etiquetas compártense).",
    "Public" : "Pública",
    "Restricted" : "Restrinxida",
    "Invisible" : "Invisíbel",
    "Created tag" : "Etiqueta creada",
    "Failed to create tag" : "Produciuse un fallo ao crear a etiqueta",
    "Updated tag" : "Etiqueta actualizada",
    "Failed to update tag" : "Produciuse un fallo ao actualizar a etiqueta",
    "Deleted tag" : "Etiqueta eliminada",
    "Failed to delete tag" : "Produciuse un fallo ao eliminar a etiqueta",
    "Create or edit tags" : "Crear ou editar etiquetas",
    "Search for a tag to edit" : "Buscar por unha etiqueta para editar",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "No tags to select" : "Non hai etiquetas para seleccionar",
    "Tag name" : "Nome da etiqueta",
    "Tag level" : "Nivel da etiqueta",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Delete" : "Eliminar",
    "Reset" : "Restabelecer",
    "Loading …" : "Cargando…",
    "_{tag1} will be set and {tag2} will be removed from 1 file._::_{tag1} will be set and {tag2} will be removed from {count} files._" : ["{tag1} vai ser definida e {tag2} vai ser retirada dun filcheiro.","{tag1} vai ser definida e {tag2} vai ser retirada de {count} filcheiros."],
    "_{tag} will be set to 1 file._::_{tag} will be set to {count} files._" : ["{tag} vai ser definida nun ficheiro.","{tag} vai ser definida en {count} ficheiros."],
    "_{tag} will be removed from 1 file._::_{tag} will be removed from {count} files._" : ["{tag} vai ser eliminada dun ficheiro.","{tag} vai ser eliminada de {count} ficheiros."],
    "_{tags} and {lastTag} will be set to 1 file._::_{tags} and {lastTag} will be set to {count} files._" : ["{tags} e {lastTag} van ser definidas nun ficheiro.","{tags} e {lastTag} van ser definidas en {count} ficheiros."],
    "_{tags} and {lastTag} will be removed from 1 file._::_{tags} and {lastTag} will be removed from {count} files._" : ["{tags} e {lastTag} van ser eliminadas dun ficheiro.","{tags} e {lastTag} van ser eliminadas de {count} ficheiros."],
    "{displayName} (hidden)" : "{displayName} (agochado)",
    "{displayName} (restricted)" : "{displayName} (restrinxido)",
    "Only admins can create new tags" : "Só a administración pode crear novas etiquetas",
    "Failed to apply tags changes" : "Produciuse un fallo ao aplicar os cambios das etiquetas",
    "Manage tags" : "Xestionar as etiquetas",
    "Applying tags changes…" : "Aplicando os cambios das etiquetas…",
    "Search or create tag" : "Buscar ou crear unha etiqueta",
    "Search tag" : "Buscar etiqueta",
    "Change tag color" : "Cambiar a cor da etiqueta",
    "Create new tag" : "Crear unha nova etiqueta",
    "Choose tags for the selected files" : "Escolla as etiquetas para os ficheiros seleccionados",
    "Cancel" : "Cancelar",
    "Apply" : "Aplicar",
    "Failed to load selected tags" : "Produciuse un fallo ao cargar as etiquetas seleccionadas",
    "Failed to load tags" : "Produciuse un fallo ao cargar as etiquetas",
    "Failed to select tag" : "Produciuse un fallo ao seleccionar a etiqueta",
    "System admin disabled tag creation. You can only use existing ones." : "A administración do sistema desactivou a creación de etiquetas. Só pode usar as existentes.",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas…",
    "Search or create collaborative tags" : "Buscar ou crear etiquetas colaborativas",
    "No tags to select, type to create a new tag" : "Non hai etiquetas que seleccionar, escriba para crear unha nova",
    "Unable to update setting" : "Non é posíbel actualizar o axuste",
    "System tag creation is now restricted to administrators" : "A creación de etiquetas do sistema agora está restrinxida aos administradores",
    "System tag creation is now allowed for everybody" : "A creación de etiquetas do sistema agora está permitida para todos",
    "System tag management" : "Xestión de etiquetas do sistema",
    "If enabled, only administrators can create and edit tags. Accounts can still assign and remove them from files." : "Se está activado, só a administración pode crear e editar etiquetas. As contas aínda poden asignalas e eliminalas dos ficheiros.",
    "Restrict tag creation and editing to administrators" : "Restrinxir a creación e edición  de etiquetas á administración do sitio",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "As etiquetas colaborativas están dispoñíbeis para todos os usuarios. As etiquetas restrinxidas son visíbeis para os usuarios, mais non poden ser asignadas por eles. As etiquetas invisíbeis son para uso interno, pois os usuarios non poden velas nin asignalas.",
    "Assigned collaborative tags" : "Etiquetas colaborativas asignadas",
    "Open in Files" : "Abrir en Ficheiros",
    "List of tags and their associated files and folders." : "Lista de etiquetas e os seus ficheiros e cartafoles asociados.",
    "No tags found" : "Non se atopou ningunha etiqueta",
    "Tags you have created will show up here." : "As etiquetas que creou aparecerán aquí.",
    "Failed to load tag" : "Produciuse un fallo ao cargar a etiqueta",
    "Failed to load last used tags" : "Produciuse un fallo ao cargar as últimas etiquetas utilizadas",
    "Missing \"Content-Location\" header" : "Falta a cabeceira «Content-Location».",
    "A tag with the same name already exists" : "Xa existe outra etiqueta co mesmo nome",
    "Failed to load tags for file" : "Produciuse un fallo ao cargar as etiquetas do ficheiro",
    "Failed to set tag for file" : "Produciuse un fallo ao definir a etiqueta para o ficheiro",
    "Failed to delete tag for file" : "Produciuse un fallo ao eliminar a etiqueta do ficheiro",
    "Collaborative tags …" : "Etiquetas colaborativas…",
    "Loading …" : "Cargando…",
    "File tags modification canceled" : "Cancelouse a modificación das etiquetas do ficheiro",
    "Select or create tags to apply to all selected files" : "Seleccionar ou crear etiquetas para aplicalas a todos os ficheiros seleccionados",
    "Select tags to apply to all selected files" : "Seleccionar etiquetas para aplicalas a todos os ficheiros seleccionados",
    "Apply changes" : "Aplicar os cambios",
    "Loading collaborative tags …" : "Cargando etiquetas colaborativas…"
},
"nplurals=2; plural=(n != 1);");
